@@ -7,7 +7,6 @@ from asyncio import Future
 from watchdog.observers import Observer
 from watchdog.events import FileSystemEventHandler
 from .loader import load_node
-from .git import GitRepo
 from .broker import BrokerClient
 from solid_node.core.refactor import RefactorRequest
 from solid_node.node.base import StlRenderStart
@@ -22,7 +21,6 @@ class Builder(FileSystemEventHandler):
         super().__init__()
         self.path = path
 
-        self.repo = GitRepo(path)
         self.file_changed = Future()
         self.observer = Observer()
 
@@ -35,39 +33,38 @@ class Builder(FileSystemEventHandler):
         logger.info('START')
         self.broker = BrokerClient()
 
-        async with self.repo.async_lock('BUILDER'):
-            try:
-                self.node = load_node(self.path)
-            except Exception as e:
-                error_message = traceback.format_exc()
-                logger.error(error_message)
-                await self.rollback(error_message)
-                sys.exit(0)
+        try:
+            self.node = load_node(self.path)
+        except Exception as e:
+            error_message = traceback.format_exc()
+            logger.error(error_message)
+            await self.report_error(error_message)
+            sys.exit(0)
 
-            try:
-                self.node.assemble()
-            except RefactorRequest as request:
-                await self.execute_refactor(request)
-            except Exception as e:
-                error_message = traceback.format_exc()
-                logger.error(error_message)
-                await self.rollback(error_message)
-                sys.exit(0)
+        try:
+            self.node.assemble()
+        except RefactorRequest as request:
+            await self.execute_refactor(request)
+        except Exception as e:
+            error_message = traceback.format_exc()
+            logger.error(error_message)
+            await self.report_error(error_message)
+            sys.exit(0)
 
-            for path in self.node.files:
-                self.observer.schedule(self, path, recursive=False)
+        for path in self.node.files:
+            self.observer.schedule(self, path, recursive=False)
 
-            self.observer.start()
+        self.observer.start()
 
-            try:
-                await self.generate_stl()
-            except RefactorRequest as request:
-                await self.execute_refactor(request)
-            except Exception as e:
-                error_message = traceback.format_exc()
-                logger.error(error_message)
-                await self.rollback(error_message)
-                sys.exit(0)
+        try:
+            await self.generate_stl()
+        except RefactorRequest as request:
+            await self.execute_refactor(request)
+        except Exception as e:
+            error_message = traceback.format_exc()
+            logger.error(error_message)
+            await self.report_error(error_message)
+            sys.exit(0)
 
         await self.file_changed
         sys.exit(0)
@@ -79,7 +76,7 @@ class Builder(FileSystemEventHandler):
         except Exception as e:
             error_message = traceback.format_exc()
             logger.error(error_message)
-            await self.rollback(f"Could not execute refactor\n\n{error_message}")
+            await self.report_error(f"Could not execute refactor\n\n{error_message}")
 
     async def generate_stl(self):
         try:
@@ -91,12 +88,12 @@ class Builder(FileSystemEventHandler):
             logger.info(f"{job.stl_file} done!")
             sys.exit(0)
 
-    async def rollback(self, error_message):
+    async def report_error(self, error_message):
         await self.broker.put('build_error', {
             'error': error_message,
             'tstamp': time.time(),
         })
-        self.repo.revert_last_commit()
+        await self.file_changed
         sys.exit(0)
 
     def on_modified(self, event):
