@@ -3,14 +3,13 @@ import * as THREE from 'three';
 import './App.css';
 import { Resizable } from 're-resizable';
 import { STLViewer, STLViewerHandles } from './viewer/STLViewer';
-//import { ControlCube } from './viewer/ControlCube';
+import { ControlCube } from './viewer/ControlCube';
 //import { NodeProvider } from './context';
 import { RotationControl } from './viewer/viewer.d';
 import { BrowserRouter as Router } from 'react-router-dom';
 import { Node, Context, loadNode } from './node';
 import { Reloader } from './reloader';
 import { Animator } from './animator';
-import CodeEditor from './CodeEditor';
 import NavigationTree from './NavigationTree';
 
 
@@ -37,6 +36,7 @@ const App = () => {
       const newContext = Object.assign({}, context, { time });
       node.setContext(newContext);
       setContext(newContext);
+      document.title = node.name.replace(/([A-Z])/g, ' $1').trim();
     }
   }, [time, node]);
 
@@ -70,34 +70,13 @@ const App = () => {
   };
   */
 
-  const fontSize = 15;
-
   return (
     <Router>
       <div className="app">
-        <div className="top">
+        <div className="body">
           <Resizable
-            defaultSize={{ width: '12%', height: '100%' }}
             className="pane left"
-            enable={{ right: true }}
-          >
-            <NavigationTree />
-          </Resizable>
-
-          <Resizable
-            className="pane center"
-            defaultSize={{ width: '46.4%', height: '100%' }}
-            enable={{ right: true }}
-          >
-            <CodeEditor
-              node={node}
-              fontSize={fontSize}
-            />
-          </Resizable>
-
-          <Resizable
-            className="pane right"
-            defaultSize={{ width: '41.6%', height: '100%' }}
+            defaultSize={{ width: '100%', height: '100%' }}
             enable={{ right: true }}
           >
             {!error &&
@@ -123,10 +102,6 @@ const App = () => {
             </div>
           </Resizable>
         </div>
-
-        <Resizable defaultSize={{ width: '100%', height: '30%' }} className="pane bottom">
-          <h3>Console</h3>
-        </Resizable>
       </div>
     </Router>
   );
