@@ -19,9 +19,9 @@ interface NodeData {
   name: string;
   model?: string;
   children?: string[];
-  code: string;
   mtime: number;
   operations: RawOperation[];
+  color: string;
 }
 
 const stlLoader = new STLLoader();
@@ -40,15 +40,13 @@ export abstract class Node {
   model?: string;
   mesh?: THREE.Mesh;
 
-  // The source code for this node
-  code: string;
-  newCode: string | undefined;
-
   children: Node[];
   context: Context;
 
   mtime: number;
 
+  color: string;
+
   // Operations matrix.
   // Each layer of the tree has a list of operations
   // rawOperations contains functions (can use $t or any variable)
@@ -61,12 +59,11 @@ export abstract class Node {
     this.path = path;
     this.name = data.name;
     this.mtime = data.mtime;
-    this.code = data.code;
     this.context = context;
     this.children = [];
     this.rawOperations = [];
     this.operations = [];
-    this.newCode = this.code;
+    this.color = data.color;
   }
 
   setOperations(op: RawOperation[], level: number = 0) {
@@ -89,38 +86,10 @@ export abstract class Node {
     this.applyOperations();
   }
 
-  setCode(code: string) {
-    this.newCode = code;
-  }
-
-  async saveCode() {
-    if (!this.newCode) {
-      alert('no code to save');
-      return;
-    }
-    const response = await fetch(
-      `/node${this.path}`,
-      {
-        method: 'POST',
-        headers: {
-          'Content-Type': 'text/plain',
-        },
-        body: this.newCode,
-      }
-    );
-    if (response.ok) {
-      this.code = this.newCode;
-    }
-  }
-
   async reload(): Promise<Node | undefined> {
     this.loadModel();
     try {
       const nodeData = await loadNodeData(this.path);
-      if (this.code != nodeData.code) {
-	this.code = nodeData.code;
-	this.newCode = this.code;
-      }
       const scene = this.context.scene;
       while(scene.children.length > 0) {
 	scene.remove(scene.children[0]);
@@ -137,6 +106,7 @@ export abstract class Node {
     const tstamp = new Date().getTime(); // avoid cache
 
     stlLoader.load(`/node${this.path}${this.model}?t=${tstamp}`, (geometry) => {
+      // TODO use this.color to colorize node
       const material = new THREE.MeshNormalMaterial();
       const mesh = new THREE.Mesh(geometry, material);
       if (this.context.scene) {
